@@ -11,7 +11,7 @@ bn.boot = function(data, statistic, R = 200, m = nrow(data), sim = "ordinary",
   # check the size of each bootstrap sample.
   m = check.bootsize(m, data)
   # check the sim parameter.
-  if (!(sim %in% c("ordinary", "parametric")))
+  if (sim %!in% c("ordinary", "parametric"))
     stop("the bootstrap simulation can be either 'ordinary' or 'parametric'.")
   # check debug.
   check.logical(debug)
@@ -139,9 +139,9 @@ bn.cv = function(data, bn, loss = NULL, k = 10, algorithm.args = list(),
     # check the loss function.
     loss = check.loss(loss, data, bn)
     # check whether it does return a DAG or not.
-    if (!(bn %in% always.dag.result) && (loss == "pred"))
-      stop(paste("this learning algorithm may result in a partially directed",
-        "or undirected network, which is not handled by parameter fitting."))
+    if ((bn %!in% always.dag.result) && (loss == "pred"))
+      stop("this learning algorithm may result in a partially directed",
+        " or undirected network, which is not handled by parameter fitting.")
     # check the extra arguments for the learning algorithm.
     algorithm.args = check.learning.algorithm.args(algorithm.args)
     # since we have no other way to guess, copy the label of the target
