@@ -6,7 +6,7 @@ check.Rgraphviz = function() {
   warning.level  = as.numeric(options("warn"))
   options("warn" = -1)
 
-  if (!require(Rgraphviz))
+  if (!requireNamespace("Rgraphviz"))
     stop("this function requires the Rgraphviz package.")
 
   # restore the original warning level.
@@ -29,13 +29,13 @@ graphviz.backend = function(nodes, arcs, highlight = NULL, arc.weights = NULL,
   # sanitize the layout (to be passed to layoutGraph).
   if (!is.string(layout))
     stop("graph layout must be a character string.")
-  if (!(layout %in% graphviz.layouts))
-    stop(paste(c("valid layout schemes are:", graphviz.layouts), collapse = " "))
+  if (layout %!in% graphviz.layouts)
+    stop("valid layout schemes are:", paste0(" '", graphviz.layouts, "'"), ".")
   # sanitize nodes' shape.
   if (!is.string(shape))
     stop("node shape must be a character string.")
-  if (!(shape %in% node.shapes))
-    stop(paste(c("valid node shapes are:", node.shapes), collapse = " "))
+  if (shape %!in% node.shapes)
+    stop("valid node schapes are:", paste0(" '", node.shapes, "'"), ".")
   # sanitize arc weights.
   if (!is.null(arc.weights)) {
 
@@ -50,9 +50,9 @@ graphviz.backend = function(nodes, arcs, highlight = NULL, arc.weights = NULL,
 
     highlighting = TRUE
 
-    if (!is.list(highlight) || !all(names(highlight) %in% highlight.params))
-      stop(paste(c("highlight must be a list with at least one of the",
-             "following elements:", highlight.params), collapse = " "))
+    if (!is.list(highlight) || any(names(highlight) %!in% highlight.params))
+      stop("highlight must be a list with at least one of the following",
+           " elements:", paste0(" '", highlight.params, "'"), ".")
 
     if ("nodes" %in% names(highlight))
       check.nodes(highlight$nodes, graph = nodes)
@@ -74,7 +74,7 @@ graphviz.backend = function(nodes, arcs, highlight = NULL, arc.weights = NULL,
 
     if ("fill" %in% names(highlight)) {
 
-      if (!("nodes" %in% names(highlight)))
+      if ("nodes" %!in% names(highlight))
         warning("no node to apply the 'fill' color to, ignoring.")
 
       check.colour(highlight$fill)
@@ -85,7 +85,7 @@ graphviz.backend = function(nodes, arcs, highlight = NULL, arc.weights = NULL,
 
     if ("lwd" %in% names(highlight)) {
 
-      if (!("arcs" %in% names(highlight)))
+      if ("arcs" %!in% names(highlight))
         warning("no arc to apply the 'lwd' setting to, ignoring.")
 
       if (!is.positive(highlight$lwd))
@@ -95,7 +95,7 @@ graphviz.backend = function(nodes, arcs, highlight = NULL, arc.weights = NULL,
 
     if ("lty" %in% names(highlight)) {
 
-      if (!("arcs" %in% names(highlight)))
+      if ("arcs" %!in% names(highlight))
         warning("no arc to apply the 'lty' setting to, ignoring.")
 
       check.lty(highlight$lty)
@@ -104,7 +104,7 @@ graphviz.backend = function(nodes, arcs, highlight = NULL, arc.weights = NULL,
 
     if ("textCol" %in% names(highlight)) {
 
-      if (!("nodes" %in% names(highlight)))
+      if ("nodes" %!in% names(highlight))
         warning("no node to apply the 'textColor' color to, ignoring.")
 
       check.colour(highlight$textCol)
@@ -120,10 +120,10 @@ graphviz.backend = function(nodes, arcs, highlight = NULL, arc.weights = NULL,
                 edgemode = 'directed')
 
   # dump the global graphical settings.
-  graph.par.dump = graph.par()
+  graph.par.dump = graph::graph.par()
 
   # set the title and the subtitle.
-  graph.par(list(graph = list(main = main, sub = sub)))
+  graph::graph.par(list(graph = list(main = main, sub = sub)))
 
   # set graph layout and global parameters.
   if (shape %in% c("ellipse", "rectangle")) {
@@ -142,14 +142,14 @@ graphviz.backend = function(nodes, arcs, highlight = NULL, arc.weights = NULL,
 
   }#THEN
 
-  graph.plot = layoutGraph(graph.obj, attrs = attrs, nodeAttrs = node.attrs,
-                 layoutType = layout)
+  graph.plot = Rgraphviz::layoutGraph(graph.obj, attrs = attrs,
+                 nodeAttrs = node.attrs, layoutType = layout)
 
   # kill the arroheads of undirected arcs.
-  u = names(which(edgeRenderInfo(graph.plot)[['direction']] == "both"))
+  u = names(which(graph::edgeRenderInfo(graph.plot)[['direction']] == "both"))
 
-  edgeRenderInfo(graph.plot)[["arrowhead"]][u] = "none"
-  edgeRenderInfo(graph.plot)[["arrowtail"]][u] = "none"
+  graph::edgeRenderInfo(graph.plot)[["arrowhead"]][u] = "none"
+  graph::edgeRenderInfo(graph.plot)[["arrowtail"]][u] = "none"
 
   # change arc line width according to arc weights.
   if (!is.null(arc.weights)) {
@@ -161,9 +161,9 @@ graphviz.backend = function(nodes, arcs, highlight = NULL, arc.weights = NULL,
       # plot an arc as a dotted line if it has a negative weight
       # (i.e. it's removal would improve the goodness of fit).
       if (arc.weights[i] > 0)
-        edgeRenderInfo(graph.plot)[["lwd"]][to.weight[i]] = arc.weights[i]
+        graph::edgeRenderInfo(graph.plot)[["lwd"]][to.weight[i]] = arc.weights[i]
       else
-        edgeRenderInfo(graph.plot)[["lty"]][to.weight[i]] = "dashed"
+        graph::edgeRenderInfo(graph.plot)[["lty"]][to.weight[i]] = "dashed"
 
     }#THEN
 
@@ -174,9 +174,9 @@ graphviz.backend = function(nodes, arcs, highlight = NULL, arc.weights = NULL,
 
     if ("nodes" %in% names(highlight)) {
 
-      nodeRenderInfo(graph.plot)[["col"]][highlight$nodes] = highlight$col
-      nodeRenderInfo(graph.plot)[["fill"]][highlight$nodes] = highlight$fill
-      nodeRenderInfo(graph.plot)[["textCol"]][highlight$nodes] = highlight$textCol
+      graph::nodeRenderInfo(graph.plot)[["col"]][highlight$nodes] = highlight$col
+      graph::nodeRenderInfo(graph.plot)[["fill"]][highlight$nodes] = highlight$fill
+      graph::nodeRenderInfo(graph.plot)[["textCol"]][highlight$nodes] = highlight$textCol
 
     }#THEN
 
@@ -184,14 +184,14 @@ graphviz.backend = function(nodes, arcs, highlight = NULL, arc.weights = NULL,
 
       to.highlight = apply(highlight$arcs, 1, paste, collapse = "~")
 
-      edgeRenderInfo(graph.plot)[["col"]][to.highlight] = highlight$col
+      graph::edgeRenderInfo(graph.plot)[["col"]][to.highlight] = highlight$col
 
       if ("lwd" %in% names(highlight))
-        edgeRenderInfo(graph.plot)[["lwd"]][to.highlight] = highlight$lwd
+        graph::edgeRenderInfo(graph.plot)[["lwd"]][to.highlight] = highlight$lwd
 
       # note that this overrides the changes made according to arc weights.
       if ("lty" %in% names(highlight))
-        edgeRenderInfo(graph.plot)[["lty"]][to.highlight] = highlight$lty
+        graph::edgeRenderInfo(graph.plot)[["lty"]][to.highlight] = highlight$lty
 
     }#THEN
 
@@ -200,19 +200,19 @@ graphviz.backend = function(nodes, arcs, highlight = NULL, arc.weights = NULL,
   # do the actual plotting.
   if (nrow(arcs) > 0) {
 
-    renderGraph(graph.plot)
+    Rgraphviz::renderGraph(graph.plot)
 
   }#THEN
   else {
 
     # use a NOP function to render arcs, the default renderEdges() raises an
     # error if the graph is empty.
-    renderGraph(graph.plot, drawEdges = function(x) {})
+    Rgraphviz::renderGraph(graph.plot, drawEdges = function(x) {})
 
   }#ELSE
 
   # restore the original global graphical settings.
-  graph.par(graph.par.dump)
+   graph::graph.par(graph.par.dump)
 
   # return (invisibly) the graph object, to allow further customizations.
   invisible(graph.plot)
