@@ -1,5 +1,6 @@
 
-# conditional and unconditional independence tests (vectorized in x).
+# conditional and unconditional independence tests (vectorized in x, scalar
+# in y).
 indep.test = function(x, y, sx, data, test, B = 0, alpha = 1, learning = TRUE) {
 
   .Call("indep_test",
@@ -14,9 +15,10 @@ indep.test = function(x, y, sx, data, test, B = 0, alpha = 1, learning = TRUE) {
 
 }#INDEP.TEST
 
-# test against all possible subsets of the conditioning set.
-allsubs.test = function(x, y, sx, data, test, B = 0, alpha = 1, min = 0,
-    max = length(sx), debug = FALSE) {
+# test against all possible subsets of the conditioning set (scalar in both x
+# and y).
+allsubs.test = function(x, y, sx, fixed = character(0), data, test, B = 0,
+    alpha = 1, min = 0, max = length(sx), debug = FALSE) {
 
   sx = sx[sx != ""]
   if (missing(max))
@@ -26,6 +28,7 @@ allsubs.test = function(x, y, sx, data, test, B = 0, alpha = 1, min = 0,
         x = x,
         y = y,
         sx = sx,
+        fixed = fixed,
         data = data,
         test = test,
         B = B,
