@@ -1,13 +1,15 @@
 
 # convert a set of arcs to a (real) edge list.
-arcs2elist = function(arcs, nodes, id = TRUE, sublist = TRUE) {
+arcs2elist = function(arcs, nodes, weights = NULL, nid = TRUE, sublist = TRUE,
+    parents = FALSE) {
 
   .Call("arcs2elist",
         arcs = arcs,
         nodes = nodes,
-        id = id,
+        weigths = weights,
+        nid = nid,
         sublist = sublist,
-        PACKAGE = "bnlearn")
+        parents = parents)
 
 }#ARCS2ELIST
 
@@ -15,8 +17,7 @@ arcs2elist = function(arcs, nodes, id = TRUE, sublist = TRUE) {
 elist2arcs = function(elist) {
 
   .Call("elist2arcs",
-        elist = elist,
-        PACKAGE = "bnlearn")
+        elist = elist)
 
 }#ELIST2ARCS
 
